Streamlit MUI Dialog Component
===

This streamlit component adds ANT Tree Select to Streamlit Appis

https://ant.design/components/tree-select/

Installation
-----------

    pip install st-ant-tree

